



nona -help
IF %ERRORLEVEL% NEQ 0 exit /B 1
cpfind -help
IF %ERRORLEVEL% NEQ 0 exit /B 1
autooptimiser -help
IF %ERRORLEVEL% NEQ 0 exit /B 1
pano_modify -help
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
